pub trait Access<T> {
type Guard: Deref<Target = T>;
// Required method
fn load(&self) -> Self::Guard;
}Expand description
Abstracts over ways code can get access to a value of type T.
This is the trait that parts of code will use when accessing a subpart of the big data structure. See the module documentation for details.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".