pub trait Access<T> {
// Required method
fn load(&mut self) -> &T;
}Expand description
Generalization of caches providing access to T.
This abstracts over all kinds of caches that can provide a cheap access to values of type T.
This is useful in cases where some code doesn’t care if the T is the whole structure or just
a part of it.
See the example at Cache::map.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".